@@ -292,29 +292,5 @@ class TestArchiveMethods(unittest.TestCase):
         self.assertEqual(out[0].sha256, 'sha256')
 
 
-class TestLicenses(unittest.TestCase):
-    def setUp(self):
-        self.frontend = PyPIFrontend()
-
-    def test_simple_case(self):
-        self.frontend.classifiers = [
-            'License :: OSI Approved :: GNU General Public License v3 (GPLv3)'
-        ]
-        guessed_licenses = self.frontend.guess_licenses(None)
-        self.assertEqual(len(guessed_licenses), 1)
-        self.assertIsInstance(guessed_licenses[0],
-                              upt.licenses.GNUGeneralPublicLicenseThree)
-
-    def test_simple_case_with_invalid_license_classifier(self):
-        self.frontend.classifiers = [
-            'License :: OSI Approved :: GNU General Public License (GPL)',
-            'License :: OSI Approved :: GNU General Public License v3 (GPLv3)'
-        ]
-        guessed_licenses = self.frontend.guess_licenses(None)
-        self.assertEqual(len(guessed_licenses), 1)
-        self.assertIsInstance(guessed_licenses[0],
-                              upt.licenses.GNUGeneralPublicLicenseThree)
-
-
 if __name__ == '__main__':
     unittest.main()
